"""Sets forth inputs and conversion mechanism based on price per share of a future
round (with potential discounts)"""

# Autogenerated, do not edit.
# Copyright © 2023 FMR LLC
#
# Based on the Open Captable Format schema:
# Copyright © 2024 Open Cap Table Coalition (https://opencaptablecoalition.com) /
# Original File: https://github.com/Open-Cap-Table-Coalition/Open-Cap-Format-OCF/t
# ree/v1.2.0/schema/types/conversion_mechanisms/SharePriceBasedConversionMechanism
# .schema.json

from pydantic import Field
from pyocf.primitives.types.conversion_mechanisms.conversionmechanism import (
    ConversionMechanism,
)
from pyocf.types.monetary import Monetary
from pyocf.types.percentage import Percentage
from typing import Annotated
from typing import Literal
from typing import Optional


class SharePriceBasedConversionMechanism(ConversionMechanism):
    """Sets forth inputs and conversion mechanism based on price per share of a future
    round (with potential discounts)
    """

    type: Annotated[Literal["PPS_BASED_CONVERSION"], Field(description="")] = (
        "PPS_BASED_CONVERSION"
    )
    description: Annotated[
        str,
        Field(
            description="A description of the specifics of the conversion - e.g. The Holder is entitled,"
            "during the Exercise Period, to purchase from the Company such number of"
            "Preferred Shares as are equal to $100,000 divided by the Exercise Price."
            "'Exercise Price' shall mean 80% of the price per share paid by the investors"
            "in the next Qualified Financing."
        ),
    ]
    discount: Optional[
        Annotated[
            bool,
            Field(
                description="True if the conversion shares should be based on a discount off the price-per-"
                "share in the next elligible financing"
            ),
        ]
    ] = None
    discount_percentage: Optional[
        Annotated[
            Percentage,
            Field(
                description="If the conversion price is base on a percent discount off the price-per-share of"
                "the next elligible financing, what is the discount percent"
            ),
        ]
    ] = None
    discount_amount: Optional[
        Annotated[
            Monetary,
            Field(
                description="If the resulting conversion shares is based on a fixed amount discount off the"
                "price-per-share of the next eilligible financing, what is the discount amount"
                "(in currency)"
            ),
        ]
    ] = None
